/*
    mybutton.c - new button class for xforms
    
    Copyright (C) 1997 by Sven Anders

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* 
 * Routines implementing the "mybutton" class
 *
 *  ob->col1 is the color of the box. ob->col2 is the color of cross/light
 *
 */

#include <forms.h>
#include "mybutton.h"

/** How to draw it */
typedef FL_BUTTON_STRUCT SPEC;

static void draw_mybutton(FL_OBJECT *ob)
{
    FL_Coord xx, yy, ww, hh;
    SPEC *sp = ob->spec;

   /* if redraw is demanded by FL_ENTER, ignore it */

   if ((sp->event == FL_ENTER) || (sp->event == FL_LEAVE)) return;

   /* draw the bounding box first */
   fl_drw_box(ob->boxtype, ob->x, ob->y, ob->w, ob->h, ob->col1, ob->bw);

   /* draw the box that contains the cross */
    ww = hh = FL_min(ob->w, ob->h) - 1;
    xx = ob->x + FL_BOUND_WIDTH;
    yy = ob->y + (ob->h - hh)/2;

   /* if pushed, draw a down box with the cross */

   if(((SPEC *)ob->spec)->val)
   {
      fl_drw_box(FL_DOWN_BOX, xx, yy, ww, hh, ob->col1, ob->bw);
      fl_drw_box(FL_FLAT_BOX, xx+abs(ob->bw), yy+abs(ob->bw), 
		              ww-2*abs(ob->bw), hh-2*abs(ob->bw), ob->col2, 0);
      /*
      fl_drw_text(FL_ALIGN_CENTER, xx-2, yy-2, ww+4, hh+4, ob->col2, 0, 0, "@9plus");
      */
   }
   else
   {
      fl_drw_box(FL_DOWN_BOX, xx, yy, ww, hh, ob->col1, ob->bw);
   }

   /* label */
   if (ob->lsize == 0)
     fl_drw_text(FL_ALIGN_LEFT, xx+ww-4, ob->y, 0, ob->h,
		 ob->lcol, ob->lstyle, (ob->h*2)/3, ob->label);
   else
     fl_drw_text(FL_ALIGN_LEFT, xx+ww-4, ob->y, 0, ob->h,
		 ob->lcol, ob->lstyle, ob->lsize, ob->label);

}

/* creation */
FL_OBJECT *fl_create_mybutton(int type, FL_Coord x, FL_Coord y, FL_Coord w,
                      FL_Coord h, const char *label)
{
     FL_OBJECT *ob;
     fl_add_button_class(FL_MYBUTTON, draw_mybutton, 0);
     ob = fl_create_generic_button(FL_MYBUTTON, type, x, y, w, h, label);
     ob->boxtype = FL_NO_BOX;
     ob->col2 = FL_YELLOW;   /* cross/light color */
     return ob;
}

FL_OBJECT *fl_add_mybutton(int type, FL_Coord x, FL_Coord y, FL_Coord w,
                   FL_Coord h, const char *label)
{
    FL_OBJECT *ob = fl_create_mybutton(type, x, y, w, h, label);
    fl_add_object(fl_current_form, ob);
    return ob;
}
